@@ -1,4 +1,4 @@
-# $Id: Directory.pm 40407 2013-10-11 09:43:39Z anton $
+# $Id: Directory.pm 40422 2013-10-14 09:00:20Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/Directory.pm $
 
 use strict;
@@ -143,9 +143,9 @@ field usePagedResults => 0;
 
 
 sub ldapError {
-	# spiffy stopt de eerste parameter in $self
-	warn "coming in LDAPERROR" if $self->debug;
+	#callback heeft geen $self
 	my $res = $self;
+	# code 4 is sizelimit exceeded
 	confess $res->error unless $res->code == 4;
 	return $res;
 }
